@@ -3,7 +3,7 @@
 /*
  *  GThumb
  *
- *  Copyright (C) 2001 The Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2003 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -143,15 +143,27 @@
 #define  PREF_WEB_ALBUM_DESTINATION   "/apps/gthumb/dialogs/web_album/destination"
 #define  PREF_WEB_ALBUM_INDEX_FILE    "/apps/gthumb/dialogs/web_album/index_file"
 #define  PREF_WEB_ALBUM_COPY_IMAGES   "/apps/gthumb/dialogs/web_album/copy_images"
+#define  PREF_WEB_ALBUM_RESIZE_IMAGES "/apps/gthumb/dialogs/web_album/resize_images"
+#define  PREF_WEB_ALBUM_RESIZE_WIDTH  "/apps/gthumb/dialogs/web_album/resize_width"
+#define  PREF_WEB_ALBUM_RESIZE_HEIGHT "/apps/gthumb/dialogs/web_album/resize_height"
 #define  PREF_WEB_ALBUM_ROWS          "/apps/gthumb/dialogs/web_album/rows"
 #define  PREF_WEB_ALBUM_COLUMNS       "/apps/gthumb/dialogs/web_album/columns"
 #define  PREF_WEB_ALBUM_SORT          "/apps/gthumb/dialogs/web_album/sort_by"
 #define  PREF_WEB_ALBUM_REVERSE       "/apps/gthumb/dialogs/web_album/reverse_order"
-#define  PREF_WEB_ALBUM_TITLE         "/apps/gthumb/dialogs/web_album/title"
+#define  PREF_WEB_ALBUM_HEADER        "/apps/gthumb/dialogs/web_album/header"
+#define  PREF_WEB_ALBUM_FOOTER        "/apps/gthumb/dialogs/web_album/footer"
 #define  PREF_WEB_ALBUM_THEME         "/apps/gthumb/dialogs/web_album/theme"
+#define  PREF_WEB_ALBUM_INDEX_CAPTION "/apps/gthumb/dialogs/web_album/index_caption"
+#define  PREF_WEB_ALBUM_IMAGE_CAPTION "/apps/gthumb/dialogs/web_album/image_caption"
 #define  PREF_SEARCH_RECURSIVE        "/apps/gthumb/dialogs/search/recursive"
 #define  PREF_PRINT_PAPER_SIZE        "/apps/gthumb/dialogs/print/paper_size"
 #define  PREF_PRINT_PAPER_ORIENTATION "/apps/gthumb/dialogs/print/paper_orientation"
+#define  PREF_PRINT_INCLUDE_COMMENT   "/apps/gthumb/dialogs/print/include_comment"
+#define  PREF_PRINT_COMMENT_FONT      "/apps/gthumb/dialogs/print/comment_font"
+#define  PREF_PRINT_PAPER_WIDTH       "/apps/gthumb/dialogs/print/paper_width"
+#define  PREF_PRINT_PAPER_HEIGHT      "/apps/gthumb/dialogs/print/paper_height"
+#define  PREF_PRINT_PAPER_UNIT        "/apps/gthumb/dialogs/print/paper_unit"
+#define  PREF_MSG_CANNOT_MOVE_TO_TRASH "/apps/gthumb/dialogs/messages/cannot_move_to_trash"
 
 
 typedef struct {
@@ -164,6 +176,7 @@ typedef struct {
 	gboolean     toolbar_detachable;
 	GthClickPolicy  nautilus_click_policy;
 	char        *nautilus_theme;
+	char        *startup_location;
 
 	/* Wallpaper options. */
 
@@ -176,6 +189,10 @@ void            preferences_init                      (void);
 
 void            preferences_release                   (void);
 
+void            preferences_set_startup_location      (const char *location);
+
+const char *    preferences_get_startup_location      (void);
+
 const  char    *pref_util_get_file_location           (const char *location);
 
 const  char    *pref_util_get_catalog_location        (const char *location);
@@ -279,4 +296,8 @@ GthPreviewContent  pref_get_preview_content        (void);
 
 GthViewMode        pref_get_view_mode              (void);
 
+void               pref_set_print_unit             (GthPrintUnit value);
+
+GthPrintUnit       pref_get_print_unit             (void);
+
 #endif /* PREFERENCES_H */
