@@ -29,17 +29,11 @@
 #include "gtk-utils.h"
 #include "gconf-utils.h"
 #include "glib-utils.h"
+#include "exif-utils.h"
 #include "file-utils.h"
 #include "dlg-file-utils.h"
 #include "preferences.h"
 
-#ifdef HAVE_LIBEXIF
-#include <exif-data.h>
-#include <exif-content.h>
-#include <exif-entry.h>
-#endif /* HAVE_LIBEXIF */
-
-
 enum {
 	RS_OLDNAME_COLUMN,
 	RS_NEWNAME_COLUMN,
@@ -50,7 +44,7 @@ int            sort_method_to_idx[] = { -1, 0, -1, 1, 2 };
 GthSortMethod  idx_to_sort_method[] = { GTH_SORT_METHOD_BY_NAME, GTH_SORT_METHOD_BY_SIZE, GTH_SORT_METHOD_BY_TIME };
 
 
-#define COMMENT_GLADE_FILE "gthumb_tools.glade"
+#define GLADE_FILE "gthumb_tools.glade"
 
 typedef struct {
 	GThumbWindow  *window;
@@ -74,8 +68,7 @@ static void
 destroy_cb (GtkWidget  *widget, 
 	    DialogData *data)
 {
-	if (data->file_list != NULL) 
-		g_list_free (data->file_list);
+	file_data_list_free (data->file_list); 
 	if (data->new_names_list != NULL) {
 		g_list_foreach (data->new_names_list, (GFunc) g_free, NULL);
 		g_list_free (data->new_names_list);
@@ -93,13 +86,12 @@ ok_clicked_cb (GtkWidget  *widget,
 	GList *old_names = NULL;
 	GList *new_names = NULL;
 	GList *o_scan, *n_scan;
-	char  *template;
+	const char  *template;
 
 	/* Save options */
 
-	template = _gtk_entry_get_locale_text (GTK_ENTRY (data->rs_template_entry));
+	template = gtk_entry_get_text (GTK_ENTRY (data->rs_template_entry));
 	eel_gconf_set_string (PREF_RENAME_SERIES_TEMPLATE, template);
-	g_free (template);
 
 	eel_gconf_set_integer (PREF_RENAME_SERIES_START_AT, gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (data->rs_start_at_spinbutton)));
 
@@ -182,64 +174,6 @@ get_compare_func_from_idx (int column_index)
 }
 
 
-#ifdef HAVE_LIBEXIF
-
-static time_t
-get_exif_time (const char *filename)
-{
-	ExifData     *edata;
-	unsigned int  i, j;
-	time_t        time = 0;
-	struct tm     tm = { 0, };
-
-	edata = exif_data_new_from_file (filename);
-
-	if (edata == NULL) 
-                return (time_t)0;
-
-	for (i = 0; i < EXIF_IFD_COUNT; i++) {
-		ExifContent *content = edata->ifd[i];
-
-		if (! edata->ifd[i] || ! edata->ifd[i]->count) 
-			continue;
-
-		for (j = 0; j < content->count; j++) {
-			ExifEntry   *e = content->entries[j];
-			char        *data;
-
-			if (! content->entries[j]) 
-				continue;
-
-			if ((e->tag != EXIF_TAG_DATE_TIME) &&
-			    (e->tag != EXIF_TAG_DATE_TIME_ORIGINAL) &&
-			    (e->tag != EXIF_TAG_DATE_TIME_DIGITIZED))
-				continue;
-
-			data = g_strdup (e->data);
-			data[4] = data[7] = data[10] = data[13] = data[16] = '\0';
-
-			tm.tm_year = atoi (data) - 1900;
-			tm.tm_mon  = atoi (data + 5) - 1;
-			tm.tm_mday = atoi (data + 8);
-			tm.tm_hour = atoi (data + 11);
-			tm.tm_min  = atoi (data + 14);
-			tm.tm_sec  = atoi (data + 17);
-			time = mktime (&tm);
-
-			g_free (data);
-
-			break;
-		}
-	}
-
-	exif_data_unref (edata);
-
-	return time;
-}
-
-#endif /* HAVE_LIBEXIF */
-
-
 static char *
 get_image_date (const char *filename)
 {
@@ -270,7 +204,7 @@ update_list (DialogData *data)
 	int     idx;
 	int     start_at;
 	char  **template;
-	char   *template_s;
+	const char   *template_s;
 
 	idx = gtk_option_menu_get_history (GTK_OPTION_MENU (data->rs_sort_optionmenu));
 	data->file_list = g_list_sort (data->file_list, get_compare_func_from_idx (idx));
@@ -280,9 +214,8 @@ update_list (DialogData *data)
 
 	/**/
 
-	template_s = _gtk_entry_get_locale_text (GTK_ENTRY (data->rs_template_entry));
+	template_s = gtk_entry_get_text (GTK_ENTRY (data->rs_template_entry));
 	template = _g_get_template_from_text (template_s);
-	g_free (template_s);
 
 	start_at = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (data->rs_start_at_spinbutton));
 
@@ -294,36 +227,51 @@ update_list (DialogData *data)
 
 	for (scan = data->file_list; scan; scan = scan->next) {
 		FileData *fdata = scan->data;
-		char     *name1;
-		char     *name_wo_ext;
+		char     *name1 = NULL;
 		char     *name2;
-		char     *image_date;
 		char     *name3;
-		char     *image_size;
 		char     *name4;
 		char     *extension;
 		char     *new_name;
 
-		name1       = _g_get_name_from_template (template, start_at++);
-		name_wo_ext = remove_extension_from_path (fdata->name);
-		name2       = _g_substitute (name1, '*', name_wo_ext);
-		image_date  = get_image_date (fdata->path);
-		name3       = _g_substitute (name2, '?', image_date);
-		image_size  = gnome_vfs_format_file_size_for_display (get_file_size (fdata->path));
-		name4       = _g_substitute (name3, '!', image_size);
+		name1 = _g_get_name_from_template (template, start_at++);
 
-		extension   = strrchr (fdata->name, '.');
-		new_name    = g_strconcat (name4, extension, NULL);
+		if (strchr (name1, '*') != NULL) {
+			char *name_wo_ext = remove_extension_from_path (fdata->name);
+			char *utf8_txt = g_filename_to_utf8 (name_wo_ext, -1, 0, 0, 0);
+			name2 = _g_substitute (name1, '*', utf8_txt);
+			g_free (name_wo_ext);
+			g_free (utf8_txt);
+		} else
+			name2 = g_strdup (name1);
 
-		data->new_names_list = g_list_prepend (data->new_names_list, new_name);
+		if (strchr (name2, '?') != NULL) {
+			char *image_date  = get_image_date (fdata->path);
+			char *utf8_txt = g_locale_to_utf8 (image_date, -1, 0, 0, 0);
+			name3 = _g_substitute (name2, '?', utf8_txt);
+			g_free (image_date);
+			g_free (utf8_txt);
+		} else
+			name3 = g_strdup (name2);
 
-		g_free (name_wo_ext);
-		g_free (image_date);
-		g_free (image_size);
+		if (strchr (name3, '!') != NULL) {
+			char *image_size = gnome_vfs_format_file_size_for_display (get_file_size (fdata->path));
+			name4 = _g_substitute (name3, '!', image_size);
+			g_free (image_size);
+		} else
+			name4 = g_strdup (name3);
+
+		extension = g_filename_to_utf8 (strrchr (fdata->name, '.'), -1, 0, 0, 0);
+		new_name = g_strconcat (name4, extension, NULL);
+
+		data->new_names_list = g_list_prepend (data->new_names_list, g_filename_from_utf8 (new_name, -1, 0, 0, 0));
+
+		g_free (extension);
 		g_free (name1);
 		g_free (name2);
 		g_free (name3);
 		g_free (name4);
+		g_free (new_name);
 	}
 	data->new_names_list = g_list_reverse (data->new_names_list);
 	g_strfreev (template);
@@ -341,8 +289,13 @@ update_list (DialogData *data)
 		
 		gtk_list_store_append (data->rs_list_model, &iter);
 		
-		utf8_on = g_locale_to_utf8 (fdata->name, -1, NULL, NULL, NULL);
-		utf8_nn = g_locale_to_utf8 (new_name, -1, NULL, NULL, NULL);
+		utf8_on = g_filename_to_utf8 (fdata->name, -1, NULL, NULL, NULL);
+		if (utf8_on == NULL)
+			utf8_on = g_strdup (_("(Invalid Name)"));
+
+		utf8_nn = g_filename_to_utf8 (new_name, -1, NULL, NULL, NULL);
+		if (utf8_nn == NULL)
+			utf8_nn = g_strdup (_("(Invalid Name)"));
 
 		gtk_list_store_set (data->rs_list_model, &iter,
 				    RS_OLDNAME_COLUMN, utf8_on,
@@ -364,6 +317,39 @@ update_list_cb (GtkWidget  *widget,
 }
 
 
+/* called when the "help" button is clicked. */
+static void
+help_cb (GtkWidget  *widget, 
+	 DialogData *data)
+{
+	GError *err;
+
+	err = NULL;  
+	gnome_help_display ("gthumb", "gthumb-rename-series", &err);
+	
+	if (err != NULL) {
+		GtkWidget *dialog;
+		
+		dialog = gtk_message_dialog_new (GTK_WINDOW (data->dialog),
+						 0,
+						 GTK_MESSAGE_ERROR,
+						 GTK_BUTTONS_CLOSE,
+						 _("Could not display help: %s"),
+						 err->message);
+		
+		g_signal_connect (G_OBJECT (dialog), "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  NULL);
+		
+		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+		
+		gtk_widget_show (dialog);
+		
+		g_error_free (err);
+	}
+}
+
+
 
 void
 dlg_rename_series (GThumbWindow *window)
@@ -371,6 +357,7 @@ dlg_rename_series (GThumbWindow *window)
 	DialogData        *data;
 	GtkWidget         *btn_ok;
 	GtkWidget         *btn_cancel;
+	GtkWidget         *help_button;
 	GList             *list;
 	GtkCellRenderer   *renderer;
 	GtkTreeViewColumn *column;
@@ -387,7 +374,7 @@ dlg_rename_series (GThumbWindow *window)
 	data->file_list = list;
 	data->new_names_list = NULL;
 	data->window = window;
-	data->gui = glade_xml_new (GTHUMB_GLADEDIR "/" COMMENT_GLADE_FILE , NULL, NULL);
+	data->gui = glade_xml_new (GTHUMB_GLADEDIR "/" GLADE_FILE , NULL, NULL);
 	if (!data->gui) {
 		g_free (data);
 		g_warning ("Could not find " GLADE_FILE "\n");
@@ -405,6 +392,7 @@ dlg_rename_series (GThumbWindow *window)
 
         btn_ok = glade_xml_get_widget (data->gui, "rs_ok_button");
         btn_cancel = glade_xml_get_widget (data->gui, "rs_cancel_button");
+	help_button = glade_xml_get_widget (data->gui, "rs_help_button");
 
 	/* Set widgets data. */
 
@@ -433,15 +421,15 @@ dlg_rename_series (GThumbWindow *window)
 
 	/**/
 
-	svalue = eel_gconf_get_string (PREF_RENAME_SERIES_TEMPLATE);
+	svalue = eel_gconf_get_string (PREF_RENAME_SERIES_TEMPLATE, "###");
 	_gtk_entry_set_locale_text (GTK_ENTRY (data->rs_template_entry), svalue);
 	g_free (svalue);
 
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (data->rs_start_at_spinbutton), eel_gconf_get_integer (PREF_RENAME_SERIES_START_AT));
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (data->rs_start_at_spinbutton), eel_gconf_get_integer (PREF_RENAME_SERIES_START_AT, 1));
 
 	gtk_option_menu_set_history (GTK_OPTION_MENU (data->rs_sort_optionmenu), sort_method_to_idx [pref_get_rename_sort_order ()]);
 
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->rs_reverse_checkbutton), eel_gconf_get_boolean (PREF_RENAME_SERIES_REVERSE));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->rs_reverse_checkbutton), eel_gconf_get_boolean (PREF_RENAME_SERIES_REVERSE, FALSE));
 
 	update_list (data);
 
@@ -459,6 +447,10 @@ dlg_rename_series (GThumbWindow *window)
 				  "clicked",
 				  G_CALLBACK (gtk_widget_destroy),
 				  G_OBJECT (data->dialog));
+	g_signal_connect (G_OBJECT (help_button), 
+			  "clicked",
+			  G_CALLBACK (help_cb),
+			  data);
 
 	g_signal_connect (G_OBJECT (data->rs_template_entry), 
 			  "changed",
